import { MarkovChainItems } from "./markov-chain-items";
import { MarkovTerminalItems } from "./markov-terminal-items";
export declare class MarkovChain<T> {
    readonly order: number;
    protected readonly items: MarkovChainItems<T>;
    protected readonly terminals: MarkovTerminalItems<T>;
    protected readonly toStrFunction: (key: T) => string;
    /**
     * Initializes a new instance of MarkovChain<T>.
     * @param order The number of state transitions to track within the model.
     * @param toStrFunction Optional function used to convert keys to strings.
     */
    constructor(order?: number, toStrFunction?: (key: T) => string);
    /**
     * Learns multiple sequences and their transitions.
     * @param items The list of sequences to learn.
     */
    learnAll(items: T[][]): void;
    /**
     * Learns a single sequence of elements.
     * @param items Lear
     */
    learn(items: T[]): void;
    private learnWithPrevious;
    /**
     * Walks the model from the beginning.
     */
    walk(): T[];
    /**
     * Walks the model, starting with the preceeding state.
     * @param previous The previous state with which to begin.
     */
    walkWithPrevious(previous: T[]): T[];
}
